@@ -16,7 +16,6 @@
 
 import argparse
 import importlib
-import inspect
 import os
 import subprocess
 import sys
@@ -27,15 +26,7 @@ from typing import Dict, List
 from accelerate.commands.config import default_config_file, load_config_from_file
 from accelerate.commands.config.config_args import SageMakerConfig
 from accelerate.state import ComputeEnvironment, DistributedType
-from accelerate.utils import is_sagemaker_available
-
-
-class _AddOneArg:
-    def __init__(self, launcher):
-        self.launcher = launcher
-
-    def __call__(self, index):
-        self.launcher()
+from accelerate.utils import PrepareForLaunch, is_sagemaker_available
 
 
 def launch_command_parser(subparsers=None):
@@ -66,10 +57,10 @@ def launch_command_parser(subparsers=None):
         "--num_processes", type=int, default=None, help="The total number of processes to be launched in parallel."
     )
     parser.add_argument(
-        "--num_machines", type=int, default=1, help="The total number of machines used in this training."
+        "--num_machines", type=int, default=None, help="The total number of machines used in this training."
     )
     parser.add_argument(
-        "--machine_rank", type=int, default=0, help="The rank of the machine on which this script is launched."
+        "--machine_rank", type=int, default=None, help="The rank of the machine on which this script is launched."
     )
     parser.add_argument("--main_process_ip", type=str, default=None, help="The IP address of the machine of rank 0.")
     parser.add_argument(
@@ -128,7 +119,7 @@ def simple_launcher(args):
 
 def multi_gpu_launcher(args):
     cmd = [sys.executable, "-m", "torch.distributed.launch"]
-    cmd.extend(["--nproc_per_node", str(args.num_processes), "--use_env"])
+    cmd.extend(["--use_env"])
     if args.num_machines > 1:
         cmd.extend(
             [
@@ -140,12 +131,14 @@ def multi_gpu_launcher(args):
                 str(args.machine_rank),
                 "--master_addr",
                 args.main_process_ip,
-                "--node_rank",
+                "--master_port",
                 str(args.main_process_port),
             ]
         )
     else:
         cmd.extend(["--nproc_per_node", str(args.num_processes)])
+        if args.main_process_port is not None:
+            cmd.extend(["--master_port", str(args.main_process_port)])
     cmd.append(args.training_script)
     cmd.extend(args.training_script_args)
 
@@ -176,12 +169,7 @@ def tpu_launcher(args):
     # Patch sys.argv
     sys.argv = [args.training_script] + args.training_script_args
 
-    # If the function does not take one argument, launch will fail
-    launcher_sig = inspect.signature(main_function)
-    if len(launcher_sig.parameters) == 0:
-        xmp.spawn(_AddOneArg(main_function), args=(), nprocs=args.num_processes)
-    else:
-        xmp.spawn(main_function, args=(), nprocs=args.num_processes)
+    xmp.spawn(PrepareForLaunch(main_function), args=(), nprocs=args.num_processes)
 
 
 def _convert_nargs_to_dict(nargs: List[str]) -> Dict[str, str]:
@@ -298,12 +286,18 @@ def launch_command(args):
         if not args.multi_gpu and not args.tpu:
             args.multi_gpu = defaults.distributed_type == DistributedType.MULTI_GPU
             args.tpu = defaults.distributed_type == DistributedType.TPU
-        if args.num_processes is None and defaults.compute_environment == ComputeEnvironment.LOCAL_MACHINE:
-            args.num_processes = defaults.num_processes
+        if defaults.compute_environment == ComputeEnvironment.LOCAL_MACHINE:
+            # Update args with the defaults
+            for name, attr in defaults.__dict__.items():
+                # Those args are handled separately
+                if (
+                    name not in ["compute_environment", "fp16", "distributed_type"]
+                    and getattr(args, name, None) is None
+                ):
+                    setattr(args, name, attr)
+
         if not args.fp16:
             args.fp16 = defaults.fp16
-        if args.main_training_function is None and defaults.compute_environment == ComputeEnvironment.LOCAL_MACHINE:
-            args.main_training_function = defaults.main_training_function
     else:
         if args.num_processes is None:
             args.num_processes = 1
