@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import importlib
+import os
 import random
 from enum import Enum
 from typing import List, Optional, Union
@@ -196,11 +197,17 @@ def pad_across_processes(tensor, dim=0, pad_index=0, pad_first=False):
     elif not isinstance(tensor, torch.Tensor):
         raise TypeError(f"Can't pad the values of type {type(tensor)}, only of nested list/tuple/dicts of tensors.")
 
+    if dim >= len(tensor.shape):
+        return tensor
+
     # Gather all sizes
     size = torch.tensor(tensor.shape, device=tensor.device)[None]
     sizes = gather(size).cpu()
     # Then pad to the maximum size
     max_size = max(s[dim] for s in sizes)
+    if max_size == tensor.shape[dim]:
+        return tensor
+
     old_size = tensor.shape
     new_size = list(old_size)
     new_size[dim] = max_size
@@ -241,3 +248,27 @@ def save(obj, f):
         xm.save(obj, f)
     elif AcceleratorState().local_process_index == 0:
         torch.save(obj, f)
+
+
+class PrepareForLaunch:
+    """
+    Prepare a function that will launched in a distributed setup.
+
+    Args:
+        launcher (:obj:`Callable`):
+            The function to launch.
+        distributed_type (:class:`~accelerate.state.DistributedType`):
+            The distributed type to prepare for.
+    """
+
+    def __init__(self, launcher, distributed_type="NO"):
+        self.launcher = launcher
+        self.distributed_type = DistributedType(distributed_type)
+
+    def __call__(self, index, *args):
+        if self.distributed_type == DistributedType.MULTI_GPU:
+            # Prepare the environment for torch.distributed
+            os.environ["LOCAL_RANK"] = str(index)
+            os.environ["RANK"] = str(index)
+
+        self.launcher(*args)
